@@ -21,6 +21,10 @@ class MobioEnvironment:
     KAFKA_BROKER = 'KAFKA_BROKER'
     KAFKA_REPLICATION_FACTOR = 'KAFKA_REPLICATION_FACTOR'
     YEK_REWOP = 'YEK_REWOP'
+    DEFAULT_BROKER_ID_ASSIGN = "DEFAULT_BROKER_ID_ASSIGN"
+    SALE_BROKER_ID_ASSIGN = "SALE_BROKER_ID_ASSIGN"
+    PROFILING_BROKER_ID_ASSIGN = "PROFILING_BROKER_ID_ASSIGN"
+    JB_BROKER_ID_ASSIGN = "JB_BROKER_ID_ASSIGN"
 
 
 KAFKA_BOOTSTRAP = os.getenv(MobioEnvironment.KAFKA_BROKER)
