@@ -1,10 +1,19 @@
 import json
-from confluent_kafka.cimpl import Producer
+from confluent_kafka.cimpl import Producer, KafkaException, KafkaError
 from mobio.libs.Singleton import Singleton
 
 from mobio.libs.kafka_lib import KAFKA_BOOTSTRAP
 
 
+def error_cb(err):
+    print("Client error: {}".format(err))
+    if err.code() == KafkaError._ALL_BROKERS_DOWN or \
+       err.code() == KafkaError._AUTHENTICATION:
+        # Any exception raised from this callback will be re-raised from the
+        # triggering flush() or poll() call.
+        raise KafkaException(err)
+
+
 @Singleton
 class KafkaProducerManager:
     producer = Producer(
@@ -12,7 +21,8 @@ class KafkaProducerManager:
                     "request.timeout.ms": 20000,
                     "bootstrap.servers": KAFKA_BOOTSTRAP,
                     "compression.type": "zstd",
-                    "linger.ms": 66,
+                    "linger.ms": 10,
+                    # 'error_cb': error_cb,
                 })
 
     def flush_message(self, topic: str, key: str, value):
